"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const swagger_jsdoc_1 = __importDefault(require("swagger-jsdoc"));
const fs_1 = require("fs");
const path_1 = require("path");
const mime_1 = __importDefault(require("mime"));
const buildJsDocConfig_1 = __importDefault(require("../src/Utils/buildJsDocConfig"));
class SwaggerProvider {
    constructor(container) {
        this.container = container;
    }
    register() { }
    boot() {
        this.initSwaggerRoutes();
    }
    initSwaggerRoutes() {
        const config = this.container.use('Adonis/Core/Config');
        const router = this.container.use('Adonis/Core/Route');
        if (config.get('swagger.uiEnabled', true)) {
            router
                .get(`${config.get('swagger.uiUrl', 'docs')}/:fileName?`, async ({ params, response }) => {
                const swaggerUiAssetPath = require('swagger-ui-dist').getAbsoluteFSPath();
                if (!params.fileName) {
                    return response.redirect('/docs/index.html');
                }
                let fileName = params.fileName ? params.fileName : 'index.html';
                const path = path_1.join(swaggerUiAssetPath, fileName);
                const contentType = mime_1.default.getType(path);
                let data = await fs_1.promises.readFile(path, 'utf-8');
                if (fileName.includes('index.html')) {
                    //replace default host from index.html
                    data = data.replace('https://petstore.swagger.io/v2/swagger.json', config.get('swagger.specUrl'));
                }
                return response.header('Content-Type', contentType).send(data);
            })
                .middleware(config.get('swagger.middleware', []));
        }
        if (config.get('swagger.specEnabled', true)) {
            router
                .get(config.get('swagger.specUrl'), () => {
                return swagger_jsdoc_1.default(buildJsDocConfig_1.default(config.get('swagger.options', {})));
            })
                .middleware(config.get('swagger.middleware', []));
        }
    }
}
exports.default = SwaggerProvider;
